@@ -2,5 +2,6 @@ from __future__ import absolute_import
 
 
 from q4nlib.misc import log
+from q4nlib.misc import utf8utils
 
-__all__ = ['log']
\ No newline at end of file
+__all__ = ['log','utf8utils']
\ No newline at end of file
